EXPORTS
	?FetchInterfaceL@TInterfaceControl@NetInterfaces@@QAEPAXH@Z @ 1 NONAME ; void * NetInterfaces::TInterfaceControl::FetchInterfaceL(int)
	?FetchInterface@TInterfaceControl@NetInterfaces@@QAEPAXH@Z @ 2 NONAME ; void * NetInterfaces::TInterfaceControl::FetchInterface(int)
	??0TInterfaceIter@NetInterfaces@@QAE@ABVTInterfaceControl@1@@Z @ 3 NONAME ; NetInterfaces::TInterfaceIter::TInterfaceIter(class NetInterfaces::TInterfaceControl const &)
	?Next@TInterfaceIter@NetInterfaces@@AAEPAXXZ @ 4 NONAME ; void * NetInterfaces::TInterfaceIter::Next(void)
	??ATInterfaceIter@NetInterfaces@@QAEPAXH@Z @ 5 NONAME ; void * NetInterfaces::TInterfaceIter::operator[](int)
	?DoFetchInterfaceControlL@AApiExtBase@NetInterfaces@@MAEPAVTInterfaceControl@2@H@Z @ 6 NONAME ; class NetInterfaces::TInterfaceControl * NetInterfaces::AApiExtBase::DoFetchInterfaceControlL(int)
	?FetchExtInterface@AApiExtBase@NetInterfaces@@QAEPAXH@Z @ 7 NONAME ; void * NetInterfaces::AApiExtBase::FetchExtInterface(int)
	?FetchExtInterfaceControlL@AApiExtBase@NetInterfaces@@QAEPAVTInterfaceControl@2@H@Z @ 8 NONAME ; class NetInterfaces::TInterfaceControl * NetInterfaces::AApiExtBase::FetchExtInterfaceControlL(int)
	?FetchExtInterfaceL@AApiExtBase@NetInterfaces@@QAEPAXH@Z @ 9 NONAME ; void * NetInterfaces::AApiExtBase::FetchExtInterfaceL(int)
	?SupportsExtInterface@AApiExtBase@NetInterfaces@@QBEHH@Z @ 10 NONAME ; int NetInterfaces::AApiExtBase::SupportsExtInterface(int) const

